# Generated by roxygen2: do not edit by hand

export(bi_class)
export(bi_class_breaks)
export(bi_legend)
export(bi_pal)
export(bi_pal_manual)
export(bi_scale_color)
export(bi_scale_fill)
export(bi_theme)
