## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----example-maps, echo=FALSE, out.width = '100%'-----------------------------
knitr::include_graphics("../man/figures/biscale.001.jpeg")

## ----quantile-breaks, echo=FALSE, out.width = '100%'--------------------------
knitr::include_graphics("../man/figures/biscale.002.jpeg")

## ----other-breaks, echo=FALSE, out.width = '100%'-----------------------------
knitr::include_graphics("../man/figures/biscale.003.jpeg")

## ----final-map, echo=FALSE, out.width = '100%'--------------------------------
knitr::include_graphics("../man/figures/biscale.004.jpeg")

